# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .document import Document
from .documents.document_version import DocumentVersion

__all__ = ["DocumentActivateResponse"]


class DocumentActivateResponse(BaseModel):
    """Response after activating a document version"""

    document: Document

    new_active_version: DocumentVersion = FieldInfo(alias="newActiveVersion")
    """A specific version of a document with its content and metadata"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..types import tag_list_params, tag_create_params, tag_update_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..types.tag import Tag
from ..pagination import SyncOffsetPagination, AsyncOffsetPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.tag_create_response import TagCreateResponse
from ..types.tag_update_response import TagUpdateResponse
from ..types.tag_retrieve_response import TagRetrieveResponse

__all__ = ["TagsResource", "AsyncTagsResource"]


class TagsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return TagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return TagsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        color: str | Omit = omit,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagCreateResponse:
        """
        Creates a new tag with the provided information.

        Args:
          name: Name of the tag

          color: Hex color code for the tag

          description: Optional description of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v0/tags",
            body=maybe_transform(
                {
                    "name": name,
                    "color": color,
                    "description": description,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagRetrieveResponse:
        """
        Retrieves detailed information about a specific tag.

        Args:
          id: The unique identifier of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/tags/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        color: str | Omit = omit,
        description: Optional[str] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagUpdateResponse:
        """
        Updates an existing tag with the provided information.

        Args:
          id: The unique identifier of the tag

          color: Hex color code for the tag

          description: Optional description of the tag

          name: Name of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v0/tags/{id}",
            body=maybe_transform(
                {
                    "color": color,
                    "description": description,
                    "name": name,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpdateResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        search: str | Omit = omit,
        skip: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncOffsetPagination[Tag]:
        """
        Retrieves a paginated list of tags with optional search filtering.

        Args:
          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          search: Search in tag name and description

          skip: Number of items to skip before starting to collect the result set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/tags",
            page=SyncOffsetPagination[Tag],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "search": search,
                        "skip": skip,
                    },
                    tag_list_params.TagListParams,
                ),
            ),
            model=Tag,
        )


class AsyncTagsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncTagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncTagsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        color: str | Omit = omit,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagCreateResponse:
        """
        Creates a new tag with the provided information.

        Args:
          name: Name of the tag

          color: Hex color code for the tag

          description: Optional description of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v0/tags",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "color": color,
                    "description": description,
                },
                tag_create_params.TagCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagRetrieveResponse:
        """
        Retrieves detailed information about a specific tag.

        Args:
          id: The unique identifier of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/tags/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        color: str | Omit = omit,
        description: Optional[str] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TagUpdateResponse:
        """
        Updates an existing tag with the provided information.

        Args:
          id: The unique identifier of the tag

          color: Hex color code for the tag

          description: Optional description of the tag

          name: Name of the tag

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v0/tags/{id}",
            body=await async_maybe_transform(
                {
                    "color": color,
                    "description": description,
                    "name": name,
                },
                tag_update_params.TagUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpdateResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        search: str | Omit = omit,
        skip: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Tag, AsyncOffsetPagination[Tag]]:
        """
        Retrieves a paginated list of tags with optional search filtering.

        Args:
          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          search: Search in tag name and description

          skip: Number of items to skip before starting to collect the result set.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/tags",
            page=AsyncOffsetPagination[Tag],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "search": search,
                        "skip": skip,
                    },
                    tag_list_params.TagListParams,
                ),
            ),
            model=Tag,
        )


class TagsResourceWithRawResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_raw_response_wrapper(
            tags.create,
        )
        self.retrieve = to_raw_response_wrapper(
            tags.retrieve,
        )
        self.update = to_raw_response_wrapper(
            tags.update,
        )
        self.list = to_raw_response_wrapper(
            tags.list,
        )


class AsyncTagsResourceWithRawResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_raw_response_wrapper(
            tags.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            tags.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            tags.update,
        )
        self.list = async_to_raw_response_wrapper(
            tags.list,
        )


class TagsResourceWithStreamingResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_streamed_response_wrapper(
            tags.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            tags.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            tags.update,
        )
        self.list = to_streamed_response_wrapper(
            tags.list,
        )


class AsyncTagsResourceWithStreamingResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_streamed_response_wrapper(
            tags.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            tags.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            tags.update,
        )
        self.list = async_to_streamed_response_wrapper(
            tags.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Tag"]


class Tag(BaseModel):
    """A tag that can be applied to documents for organization"""

    id: str
    """Unique identifier of the tag"""

    color: str
    """Hex color code for the tag"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the tag was created"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the tag was last modified"""

    name: str
    """Name of the tag"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this tag"""

    application_id: Optional[str] = FieldInfo(alias="applicationId", default=None)
    """Optional application ID this tag belongs to"""

    description: Optional[str] = None
    """Optional description of the tag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .eval_type import EvalType
from .application import Application

__all__ = [
    "EvalDefinition",
    "GlobalConfig",
    "GlobalConfigCriterion",
    "GlobalConfigGroundTruth",
    "GlobalConfigOutputMatchStringConfigOutput",
    "GlobalConfigOutputMatchStringConfigOutputExtract",
    "GlobalConfigOutputMatchListConfigOutput",
    "GlobalConfigOutputMatchListConfigOutputExtract",
]


class GlobalConfigCriterion(BaseModel):
    criterion: str
    """The criterion describes what our evaluation LLM must look for in the response.

    Remember that the answer to the criterion must be as a pass/fail.
    """


class GlobalConfigGroundTruth(BaseModel):
    ground_truth: str = FieldInfo(alias="groundTruth")
    """
    The ground truth is the most correct answer to the task that we measure the
    response against
    """


class GlobalConfigOutputMatchStringConfigOutputExtract(BaseModel):
    flags: str

    group: Union[int, List[int]]

    pattern: str


class GlobalConfigOutputMatchStringConfigOutput(BaseModel):
    type: Literal["string"]

    extract: Optional[GlobalConfigOutputMatchStringConfigOutputExtract] = None


class GlobalConfigOutputMatchListConfigOutputExtract(BaseModel):
    flags: str

    group: Union[int, List[int]]

    pattern: str


class GlobalConfigOutputMatchListConfigOutput(BaseModel):
    match_mode: Literal["exact_unordered", "contains"] = FieldInfo(alias="matchMode")

    type: Literal["list"]

    extract: Optional[GlobalConfigOutputMatchListConfigOutputExtract] = None

    pass_threshold: Optional[float] = FieldInfo(alias="passThreshold", default=None)

    score_metric: Optional[Literal["f1", "precision", "recall"]] = FieldInfo(alias="scoreMetric", default=None)


GlobalConfig: TypeAlias = Union[
    GlobalConfigCriterion,
    GlobalConfigGroundTruth,
    GlobalConfigOutputMatchStringConfigOutput,
    GlobalConfigOutputMatchListConfigOutput,
]


class EvalDefinition(BaseModel):
    id: str

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the eval definition was created"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the eval definition was last modified"""

    name: str

    type: EvalType

    application: Optional[Application] = None
    """Application configuration and metadata"""

    global_config: Optional[GlobalConfig] = FieldInfo(alias="globalConfig", default=None)

    style_guide_id: Optional[str] = FieldInfo(alias="styleGuideId", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.documents import version_update_params
from ...types.documents.version_list_response import VersionListResponse
from ...types.documents.version_create_response import VersionCreateResponse
from ...types.documents.version_update_response import VersionUpdateResponse
from ...types.documents.version_retrieve_response import VersionRetrieveResponse

__all__ = ["VersionsResource", "AsyncVersionsResource"]


class VersionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> VersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return VersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> VersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return VersionsResourceWithStreamingResponse(self)

    def create(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionCreateResponse:
        """Creates a new version of an existing document.

        The new version will have the
        next version number.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/v0/documents/{id}/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionCreateResponse,
        )

    def retrieve(
        self,
        version_number: int,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRetrieveResponse:
        """
        Retrieves a specific version of a document by version number.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/documents/{id}/versions/{version_number}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionRetrieveResponse,
        )

    def update(
        self,
        version_number: int,
        *,
        id: str,
        content: str | Omit = omit,
        language: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        original_sentences: SequenceNotStr[str] | Omit = omit,
        status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionUpdateResponse:
        """
        Updates the content, title, status, or other fields of a specific document
        version.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          content: Updated content for the version

          language: Language of the initial document version

          metadata: Updated metadata for the version

          original_sentences: Updated array of original sentences from the source

          status: Updated status for the version

          title: Updated title for the version

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v0/documents/{id}/versions/{version_number}",
            body=maybe_transform(
                {
                    "content": content,
                    "language": language,
                    "metadata": metadata,
                    "original_sentences": original_sentences,
                    "status": status,
                    "title": title,
                },
                version_update_params.VersionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionUpdateResponse,
        )

    def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionListResponse:
        """
        Retrieves all versions of a specific document, ordered by version number
        descending.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/documents/{id}/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )


class AsyncVersionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncVersionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncVersionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncVersionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncVersionsResourceWithStreamingResponse(self)

    async def create(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionCreateResponse:
        """Creates a new version of an existing document.

        The new version will have the
        next version number.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/v0/documents/{id}/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionCreateResponse,
        )

    async def retrieve(
        self,
        version_number: int,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionRetrieveResponse:
        """
        Retrieves a specific version of a document by version number.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/documents/{id}/versions/{version_number}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionRetrieveResponse,
        )

    async def update(
        self,
        version_number: int,
        *,
        id: str,
        content: str | Omit = omit,
        language: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        original_sentences: SequenceNotStr[str] | Omit = omit,
        status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionUpdateResponse:
        """
        Updates the content, title, status, or other fields of a specific document
        version.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          content: Updated content for the version

          language: Language of the initial document version

          metadata: Updated metadata for the version

          original_sentences: Updated array of original sentences from the source

          status: Updated status for the version

          title: Updated title for the version

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v0/documents/{id}/versions/{version_number}",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "language": language,
                    "metadata": metadata,
                    "original_sentences": original_sentences,
                    "status": status,
                    "title": title,
                },
                version_update_params.VersionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionUpdateResponse,
        )

    async def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> VersionListResponse:
        """
        Retrieves all versions of a specific document, ordered by version number
        descending.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/documents/{id}/versions",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=VersionListResponse,
        )


class VersionsResourceWithRawResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.create = to_raw_response_wrapper(
            versions.create,
        )
        self.retrieve = to_raw_response_wrapper(
            versions.retrieve,
        )
        self.update = to_raw_response_wrapper(
            versions.update,
        )
        self.list = to_raw_response_wrapper(
            versions.list,
        )


class AsyncVersionsResourceWithRawResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.create = async_to_raw_response_wrapper(
            versions.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            versions.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            versions.update,
        )
        self.list = async_to_raw_response_wrapper(
            versions.list,
        )


class VersionsResourceWithStreamingResponse:
    def __init__(self, versions: VersionsResource) -> None:
        self._versions = versions

        self.create = to_streamed_response_wrapper(
            versions.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            versions.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            versions.update,
        )
        self.list = to_streamed_response_wrapper(
            versions.list,
        )


class AsyncVersionsResourceWithStreamingResponse:
    def __init__(self, versions: AsyncVersionsResource) -> None:
        self._versions = versions

        self.create = async_to_streamed_response_wrapper(
            versions.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            versions.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            versions.update,
        )
        self.list = async_to_streamed_response_wrapper(
            versions.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel
from .eval_definition import EvalDefinition

__all__ = ["DefinitionCreateResponse"]


class DefinitionCreateResponse(BaseModel):
    """Response containing an eval definition"""

    data: EvalDefinition



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tag import Tag as Tag
from .task import Task as Task
from .topic import Topic as Topic
from .trace import Trace as Trace
from .core_tag import CoreTag as CoreTag
from .document import Document as Document
from .run_type import RunType as RunType
from .eval_type import EvalType as EvalType
from .issue_type import IssueType as IssueType
from .application import Application as Application
from .style_guide import StyleGuide as StyleGuide
from .test_result import TestResult as TestResult
from .usage_param import UsageParam as UsageParam
from .issue_source import IssueSource as IssueSource
from .issue_status import IssueStatus as IssueStatus
from .issue_priority import IssuePriority as IssuePriority
from .eval_definition import EvalDefinition as EvalDefinition
from .tag_list_params import TagListParams as TagListParams
from .task_list_params import TaskListParams as TaskListParams
from .test_list_params import TestListParams as TestListParams
from .tag_create_params import TagCreateParams as TagCreateParams
from .tag_update_params import TagUpdateParams as TagUpdateParams
from .topic_list_params import TopicListParams as TopicListParams
from .trace_list_params import TraceListParams as TraceListParams
from .task_create_params import TaskCreateParams as TaskCreateParams
from .task_list_response import TaskListResponse as TaskListResponse
from .task_update_params import TaskUpdateParams as TaskUpdateParams
from .test_list_response import TestListResponse as TestListResponse
from .issue_create_params import IssueCreateParams as IssueCreateParams
from .style_guide_section import StyleGuideSection as StyleGuideSection
from .tag_create_response import TagCreateResponse as TagCreateResponse
from .tag_update_response import TagUpdateResponse as TagUpdateResponse
from .task_trigger_params import TaskTriggerParams as TaskTriggerParams
from .topic_create_params import TopicCreateParams as TopicCreateParams
from .document_list_params import DocumentListParams as DocumentListParams
from .ingest_create_params import IngestCreateParams as IngestCreateParams
from .task_create_response import TaskCreateResponse as TaskCreateResponse
from .task_update_response import TaskUpdateResponse as TaskUpdateResponse
from .tag_retrieve_response import TagRetrieveResponse as TagRetrieveResponse
from .topic_create_response import TopicCreateResponse as TopicCreateResponse
from .definition_link_params import DefinitionLinkParams as DefinitionLinkParams
from .definition_list_params import DefinitionListParams as DefinitionListParams
from .document_create_params import DocumentCreateParams as DocumentCreateParams
from .document_list_response import DocumentListResponse as DocumentListResponse
from .ingest_create_response import IngestCreateResponse as IngestCreateResponse
from .task_retrieve_response import TaskRetrieveResponse as TaskRetrieveResponse
from .test_retrieve_response import TestRetrieveResponse as TestRetrieveResponse
from .application_list_params import ApplicationListParams as ApplicationListParams
from .style_guide_list_params import StyleGuideListParams as StyleGuideListParams
from .topic_retrieve_response import TopicRetrieveResponse as TopicRetrieveResponse
from .trace_retrieve_response import TraceRetrieveResponse as TraceRetrieveResponse
from .definition_create_params import DefinitionCreateParams as DefinitionCreateParams
from .definition_unlink_params import DefinitionUnlinkParams as DefinitionUnlinkParams
from .definition_update_params import DefinitionUpdateParams as DefinitionUpdateParams
from .document_create_response import DocumentCreateResponse as DocumentCreateResponse
from .style_guide_create_params import StyleGuideCreateParams as StyleGuideCreateParams
from .style_guide_update_params import StyleGuideUpdateParams as StyleGuideUpdateParams
from .definition_create_response import DefinitionCreateResponse as DefinitionCreateResponse
from .definition_update_response import DefinitionUpdateResponse as DefinitionUpdateResponse
from .document_activate_response import DocumentActivateResponse as DocumentActivateResponse
from .document_retrieve_response import DocumentRetrieveResponse as DocumentRetrieveResponse
from .style_guide_create_response import StyleGuideCreateResponse as StyleGuideCreateResponse
from .style_guide_update_response import StyleGuideUpdateResponse as StyleGuideUpdateResponse
from .application_retrieve_response import ApplicationRetrieveResponse as ApplicationRetrieveResponse
from .style_guide_retrieve_response import StyleGuideRetrieveResponse as StyleGuideRetrieveResponse
from .trace_retrieve_by_test_response import TraceRetrieveByTestResponse as TraceRetrieveByTestResponse
from .validate_webhook_validate_params import ValidateWebhookValidateParams as ValidateWebhookValidateParams
from .validate_webhook_validate_response import ValidateWebhookValidateResponse as ValidateWebhookValidateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..types import ingest_create_params
from .._types import Body, Query, Headers, NotGiven, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.ingest_create_response import IngestCreateResponse

__all__ = ["IngestResource", "AsyncIngestResource"]


class IngestResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IngestResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return IngestResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IngestResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return IngestResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        events: Iterable[ingest_create_params.Event],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestCreateResponse:
        """
        Ingest an array of events (traces or steps) to store and process.

        Args:
          events: Array of events to be ingested, which can be traces or steps.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v0/ingest",
            body=maybe_transform({"events": events}, ingest_create_params.IngestCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IngestCreateResponse,
        )


class AsyncIngestResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIngestResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncIngestResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIngestResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncIngestResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        events: Iterable[ingest_create_params.Event],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestCreateResponse:
        """
        Ingest an array of events (traces or steps) to store and process.

        Args:
          events: Array of events to be ingested, which can be traces or steps.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v0/ingest",
            body=await async_maybe_transform({"events": events}, ingest_create_params.IngestCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IngestCreateResponse,
        )


class IngestResourceWithRawResponse:
    def __init__(self, ingest: IngestResource) -> None:
        self._ingest = ingest

        self.create = to_raw_response_wrapper(
            ingest.create,
        )


class AsyncIngestResourceWithRawResponse:
    def __init__(self, ingest: AsyncIngestResource) -> None:
        self._ingest = ingest

        self.create = async_to_raw_response_wrapper(
            ingest.create,
        )


class IngestResourceWithStreamingResponse:
    def __init__(self, ingest: IngestResource) -> None:
        self._ingest = ingest

        self.create = to_streamed_response_wrapper(
            ingest.create,
        )


class AsyncIngestResourceWithStreamingResponse:
    def __init__(self, ingest: AsyncIngestResource) -> None:
        self._ingest = ingest

        self.create = async_to_streamed_response_wrapper(
            ingest.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from ...types import document_list_params, document_create_params
from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncOffsetPagination, AsyncOffsetPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.document_list_response import DocumentListResponse
from ...types.document_create_response import DocumentCreateResponse
from ...types.document_activate_response import DocumentActivateResponse
from ...types.document_retrieve_response import DocumentRetrieveResponse

__all__ = ["DocumentsResource", "AsyncDocumentsResource"]


class DocumentsResource(SyncAPIResource):
    @cached_property
    def versions(self) -> VersionsResource:
        return VersionsResource(self._client)

    @cached_property
    def tags(self) -> TagsResource:
        return TagsResource(self._client)

    @cached_property
    def with_raw_response(self) -> DocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return DocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return DocumentsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        content: str,
        title: str,
        assignee: str | Omit = omit,
        language: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        original_sentences: SequenceNotStr[str] | Omit = omit,
        quickstart_id: str | Omit = omit,
        scrape_job_id: str | Omit = omit,
        status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"] | Omit = omit,
        topic_id: str | Omit = omit,
        type: Literal["KNOWLEDGE", "POLICY"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentCreateResponse:
        """
        Creates a new document with the provided information.

        Args:
          content: Content of the initial document version

          title: Title of the initial document version

          assignee: User ID of the person assigned to this document. Defaults to the authenticated
              user if not provided.

          language: Language of the initial document version

          metadata: Optional metadata for the initial document version

          original_sentences: Array of original sentences from the source

          quickstart_id: Optional ID of the QuickstartV2 this document belongs to

          scrape_job_id: Optional ID of the scrape job that generated this document

          status: Status of the initial document version

          topic_id: Optional ID of the topic this document belongs to

          type: Type of the document. Defaults to KNOWLEDGE.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v0/documents",
            body=maybe_transform(
                {
                    "content": content,
                    "title": title,
                    "assignee": assignee,
                    "language": language,
                    "metadata": metadata,
                    "original_sentences": original_sentences,
                    "quickstart_id": quickstart_id,
                    "scrape_job_id": scrape_job_id,
                    "status": status,
                    "topic_id": topic_id,
                    "type": type,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentRetrieveResponse:
        """
        Retrieves detailed information about a specific document, including its
        parent-child relationships and active version details.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentRetrieveResponse,
        )

    def list(
        self,
        *,
        assignee: str | Omit = omit,
        end_date: Union[str, datetime] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        scrape_job_id: SequenceNotStr[str] | Omit = omit,
        search: str | Omit = omit,
        skip: int | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        status: List[Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]] | Omit = omit,
        tag_id: SequenceNotStr[str] | Omit = omit,
        type: Literal["KNOWLEDGE", "POLICY"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncOffsetPagination[DocumentListResponse]:
        """
        Retrieves a paginated list of documents with optional filtering by status,
        assignee, parent, and other criteria. Only returns documents with active
        approved versions unless otherwise specified.

        Args:
          assignee: Filter by assignee user ID

          end_date: Filter documents created before this date (inclusive).

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          scrape_job_id: Filter by scrape job ID. Supports multiple values.

          search: Search in document version title and content

          skip: Number of items to skip before starting to collect the result set.

          start_date: Filter documents created after this date (inclusive).

          status: Filter by document version status (filters documents by their active version
              status). Supports multiple values.

          tag_id: Filter documents by tag ID

          type: Filter by document type. Defaults to KNOWLEDGE if not specified.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/documents",
            page=SyncOffsetPagination[DocumentListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "assignee": assignee,
                        "end_date": end_date,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "scrape_job_id": scrape_job_id,
                        "search": search,
                        "skip": skip,
                        "start_date": start_date,
                        "status": status,
                        "tag_id": tag_id,
                        "type": type,
                    },
                    document_list_params.DocumentListParams,
                ),
            ),
            model=DocumentListResponse,
        )

    def activate(
        self,
        version_number: int,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentActivateResponse:
        """Makes a specific version the active version of a document.

        This is the version
        that will be returned by default when fetching the document.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v0/documents/{id}/versions/{version_number}/activate",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentActivateResponse,
        )


class AsyncDocumentsResource(AsyncAPIResource):
    @cached_property
    def versions(self) -> AsyncVersionsResource:
        return AsyncVersionsResource(self._client)

    @cached_property
    def tags(self) -> AsyncTagsResource:
        return AsyncTagsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncDocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncDocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncDocumentsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        content: str,
        title: str,
        assignee: str | Omit = omit,
        language: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        original_sentences: SequenceNotStr[str] | Omit = omit,
        quickstart_id: str | Omit = omit,
        scrape_job_id: str | Omit = omit,
        status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"] | Omit = omit,
        topic_id: str | Omit = omit,
        type: Literal["KNOWLEDGE", "POLICY"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentCreateResponse:
        """
        Creates a new document with the provided information.

        Args:
          content: Content of the initial document version

          title: Title of the initial document version

          assignee: User ID of the person assigned to this document. Defaults to the authenticated
              user if not provided.

          language: Language of the initial document version

          metadata: Optional metadata for the initial document version

          original_sentences: Array of original sentences from the source

          quickstart_id: Optional ID of the QuickstartV2 this document belongs to

          scrape_job_id: Optional ID of the scrape job that generated this document

          status: Status of the initial document version

          topic_id: Optional ID of the topic this document belongs to

          type: Type of the document. Defaults to KNOWLEDGE.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v0/documents",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "title": title,
                    "assignee": assignee,
                    "language": language,
                    "metadata": metadata,
                    "original_sentences": original_sentences,
                    "quickstart_id": quickstart_id,
                    "scrape_job_id": scrape_job_id,
                    "status": status,
                    "topic_id": topic_id,
                    "type": type,
                },
                document_create_params.DocumentCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentRetrieveResponse:
        """
        Retrieves detailed information about a specific document, including its
        parent-child relationships and active version details.

        Args:
          id: The unique identifier of the document

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/documents/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentRetrieveResponse,
        )

    def list(
        self,
        *,
        assignee: str | Omit = omit,
        end_date: Union[str, datetime] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        scrape_job_id: SequenceNotStr[str] | Omit = omit,
        search: str | Omit = omit,
        skip: int | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        status: List[Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]] | Omit = omit,
        tag_id: SequenceNotStr[str] | Omit = omit,
        type: Literal["KNOWLEDGE", "POLICY"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[DocumentListResponse, AsyncOffsetPagination[DocumentListResponse]]:
        """
        Retrieves a paginated list of documents with optional filtering by status,
        assignee, parent, and other criteria. Only returns documents with active
        approved versions unless otherwise specified.

        Args:
          assignee: Filter by assignee user ID

          end_date: Filter documents created before this date (inclusive).

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          scrape_job_id: Filter by scrape job ID. Supports multiple values.

          search: Search in document version title and content

          skip: Number of items to skip before starting to collect the result set.

          start_date: Filter documents created after this date (inclusive).

          status: Filter by document version status (filters documents by their active version
              status). Supports multiple values.

          tag_id: Filter documents by tag ID

          type: Filter by document type. Defaults to KNOWLEDGE if not specified.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/documents",
            page=AsyncOffsetPagination[DocumentListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "assignee": assignee,
                        "end_date": end_date,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "scrape_job_id": scrape_job_id,
                        "search": search,
                        "skip": skip,
                        "start_date": start_date,
                        "status": status,
                        "tag_id": tag_id,
                        "type": type,
                    },
                    document_list_params.DocumentListParams,
                ),
            ),
            model=DocumentListResponse,
        )

    async def activate(
        self,
        version_number: int,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentActivateResponse:
        """Makes a specific version the active version of a document.

        This is the version
        that will be returned by default when fetching the document.

        Args:
          id: The unique identifier of the document

          version_number: The version number

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v0/documents/{id}/versions/{version_number}/activate",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DocumentActivateResponse,
        )


class DocumentsResourceWithRawResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.create = to_raw_response_wrapper(
            documents.create,
        )
        self.retrieve = to_raw_response_wrapper(
            documents.retrieve,
        )
        self.list = to_raw_response_wrapper(
            documents.list,
        )
        self.activate = to_raw_response_wrapper(
            documents.activate,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithRawResponse:
        return VersionsResourceWithRawResponse(self._documents.versions)

    @cached_property
    def tags(self) -> TagsResourceWithRawResponse:
        return TagsResourceWithRawResponse(self._documents.tags)


class AsyncDocumentsResourceWithRawResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.create = async_to_raw_response_wrapper(
            documents.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            documents.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            documents.list,
        )
        self.activate = async_to_raw_response_wrapper(
            documents.activate,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithRawResponse:
        return AsyncVersionsResourceWithRawResponse(self._documents.versions)

    @cached_property
    def tags(self) -> AsyncTagsResourceWithRawResponse:
        return AsyncTagsResourceWithRawResponse(self._documents.tags)


class DocumentsResourceWithStreamingResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.create = to_streamed_response_wrapper(
            documents.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            documents.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            documents.list,
        )
        self.activate = to_streamed_response_wrapper(
            documents.activate,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithStreamingResponse:
        return VersionsResourceWithStreamingResponse(self._documents.versions)

    @cached_property
    def tags(self) -> TagsResourceWithStreamingResponse:
        return TagsResourceWithStreamingResponse(self._documents.tags)


class AsyncDocumentsResourceWithStreamingResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.create = async_to_streamed_response_wrapper(
            documents.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            documents.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            documents.list,
        )
        self.activate = async_to_streamed_response_wrapper(
            documents.activate,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithStreamingResponse:
        return AsyncVersionsResourceWithStreamingResponse(self._documents.versions)

    @cached_property
    def tags(self) -> AsyncTagsResourceWithStreamingResponse:
        return AsyncTagsResourceWithStreamingResponse(self._documents.tags)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import validate_webhook_validate_params
from .._types import Body, Query, Headers, NotGiven, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.validate_webhook_validate_response import ValidateWebhookValidateResponse

__all__ = ["ValidateWebhookResource", "AsyncValidateWebhookResource"]


class ValidateWebhookResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ValidateWebhookResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return ValidateWebhookResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ValidateWebhookResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return ValidateWebhookResourceWithStreamingResponse(self)

    def validate(
        self,
        *,
        body: validate_webhook_validate_params.Body,
        signature: str,
        timestamp: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ValidateWebhookValidateResponse:
        """
        Checks the body (including timestamp and signature) against the configured
        webhook secret. Returns `{ valid: true }` if the signature is valid.

        Args:
          body: The payload received from Avido. Use this in signature verification.

          signature: HMAC signature for the request body.

          timestamp: Timestamp for the request. Accepts unix milliseconds (string/number) and ISO
              date strings.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v0/validate-webhook",
            body=maybe_transform(
                {
                    "body": body,
                    "signature": signature,
                    "timestamp": timestamp,
                },
                validate_webhook_validate_params.ValidateWebhookValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ValidateWebhookValidateResponse,
        )


class AsyncValidateWebhookResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncValidateWebhookResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncValidateWebhookResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncValidateWebhookResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncValidateWebhookResourceWithStreamingResponse(self)

    async def validate(
        self,
        *,
        body: validate_webhook_validate_params.Body,
        signature: str,
        timestamp: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ValidateWebhookValidateResponse:
        """
        Checks the body (including timestamp and signature) against the configured
        webhook secret. Returns `{ valid: true }` if the signature is valid.

        Args:
          body: The payload received from Avido. Use this in signature verification.

          signature: HMAC signature for the request body.

          timestamp: Timestamp for the request. Accepts unix milliseconds (string/number) and ISO
              date strings.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v0/validate-webhook",
            body=await async_maybe_transform(
                {
                    "body": body,
                    "signature": signature,
                    "timestamp": timestamp,
                },
                validate_webhook_validate_params.ValidateWebhookValidateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ValidateWebhookValidateResponse,
        )


class ValidateWebhookResourceWithRawResponse:
    def __init__(self, validate_webhook: ValidateWebhookResource) -> None:
        self._validate_webhook = validate_webhook

        self.validate = to_raw_response_wrapper(
            validate_webhook.validate,
        )


class AsyncValidateWebhookResourceWithRawResponse:
    def __init__(self, validate_webhook: AsyncValidateWebhookResource) -> None:
        self._validate_webhook = validate_webhook

        self.validate = async_to_raw_response_wrapper(
            validate_webhook.validate,
        )


class ValidateWebhookResourceWithStreamingResponse:
    def __init__(self, validate_webhook: ValidateWebhookResource) -> None:
        self._validate_webhook = validate_webhook

        self.validate = to_streamed_response_wrapper(
            validate_webhook.validate,
        )


class AsyncValidateWebhookResourceWithStreamingResponse:
    def __init__(self, validate_webhook: AsyncValidateWebhookResource) -> None:
        self._validate_webhook = validate_webhook

        self.validate = async_to_streamed_response_wrapper(
            validate_webhook.validate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .tasks import (
    TasksResource,
    AsyncTasksResource,
    TasksResourceWithRawResponse,
    AsyncTasksResourceWithRawResponse,
    TasksResourceWithStreamingResponse,
    AsyncTasksResourceWithStreamingResponse,
)
from .tests import (
    TestsResource,
    AsyncTestsResource,
    TestsResourceWithRawResponse,
    AsyncTestsResourceWithRawResponse,
    TestsResourceWithStreamingResponse,
    AsyncTestsResourceWithStreamingResponse,
)
from .ingest import (
    IngestResource,
    AsyncIngestResource,
    IngestResourceWithRawResponse,
    AsyncIngestResourceWithRawResponse,
    IngestResourceWithStreamingResponse,
    AsyncIngestResourceWithStreamingResponse,
)
from .issues import (
    IssuesResource,
    AsyncIssuesResource,
    IssuesResourceWithRawResponse,
    AsyncIssuesResourceWithRawResponse,
    IssuesResourceWithStreamingResponse,
    AsyncIssuesResourceWithStreamingResponse,
)
from .topics import (
    TopicsResource,
    AsyncTopicsResource,
    TopicsResourceWithRawResponse,
    AsyncTopicsResourceWithRawResponse,
    TopicsResourceWithStreamingResponse,
    AsyncTopicsResourceWithStreamingResponse,
)
from .traces import (
    TracesResource,
    AsyncTracesResource,
    TracesResourceWithRawResponse,
    AsyncTracesResourceWithRawResponse,
    TracesResourceWithStreamingResponse,
    AsyncTracesResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)
from .definitions import (
    DefinitionsResource,
    AsyncDefinitionsResource,
    DefinitionsResourceWithRawResponse,
    AsyncDefinitionsResourceWithRawResponse,
    DefinitionsResourceWithStreamingResponse,
    AsyncDefinitionsResourceWithStreamingResponse,
)
from .applications import (
    ApplicationsResource,
    AsyncApplicationsResource,
    ApplicationsResourceWithRawResponse,
    AsyncApplicationsResourceWithRawResponse,
    ApplicationsResourceWithStreamingResponse,
    AsyncApplicationsResourceWithStreamingResponse,
)
from .style_guides import (
    StyleGuidesResource,
    AsyncStyleGuidesResource,
    StyleGuidesResourceWithRawResponse,
    AsyncStyleGuidesResourceWithRawResponse,
    StyleGuidesResourceWithStreamingResponse,
    AsyncStyleGuidesResourceWithStreamingResponse,
)
from .validate_webhook import (
    ValidateWebhookResource,
    AsyncValidateWebhookResource,
    ValidateWebhookResourceWithRawResponse,
    AsyncValidateWebhookResourceWithRawResponse,
    ValidateWebhookResourceWithStreamingResponse,
    AsyncValidateWebhookResourceWithStreamingResponse,
)

__all__ = [
    "ValidateWebhookResource",
    "AsyncValidateWebhookResource",
    "ValidateWebhookResourceWithRawResponse",
    "AsyncValidateWebhookResourceWithRawResponse",
    "ValidateWebhookResourceWithStreamingResponse",
    "AsyncValidateWebhookResourceWithStreamingResponse",
    "ApplicationsResource",
    "AsyncApplicationsResource",
    "ApplicationsResourceWithRawResponse",
    "AsyncApplicationsResourceWithRawResponse",
    "ApplicationsResourceWithStreamingResponse",
    "AsyncApplicationsResourceWithStreamingResponse",
    "TracesResource",
    "AsyncTracesResource",
    "TracesResourceWithRawResponse",
    "AsyncTracesResourceWithRawResponse",
    "TracesResourceWithStreamingResponse",
    "AsyncTracesResourceWithStreamingResponse",
    "IngestResource",
    "AsyncIngestResource",
    "IngestResourceWithRawResponse",
    "AsyncIngestResourceWithRawResponse",
    "IngestResourceWithStreamingResponse",
    "AsyncIngestResourceWithStreamingResponse",
    "TasksResource",
    "AsyncTasksResource",
    "TasksResourceWithRawResponse",
    "AsyncTasksResourceWithRawResponse",
    "TasksResourceWithStreamingResponse",
    "AsyncTasksResourceWithStreamingResponse",
    "DefinitionsResource",
    "AsyncDefinitionsResource",
    "DefinitionsResourceWithRawResponse",
    "AsyncDefinitionsResourceWithRawResponse",
    "DefinitionsResourceWithStreamingResponse",
    "AsyncDefinitionsResourceWithStreamingResponse",
    "TestsResource",
    "AsyncTestsResource",
    "TestsResourceWithRawResponse",
    "AsyncTestsResourceWithRawResponse",
    "TestsResourceWithStreamingResponse",
    "AsyncTestsResourceWithStreamingResponse",
    "TopicsResource",
    "AsyncTopicsResource",
    "TopicsResourceWithRawResponse",
    "AsyncTopicsResourceWithRawResponse",
    "TopicsResourceWithStreamingResponse",
    "AsyncTopicsResourceWithStreamingResponse",
    "IssuesResource",
    "AsyncIssuesResource",
    "IssuesResourceWithRawResponse",
    "AsyncIssuesResourceWithRawResponse",
    "IssuesResourceWithStreamingResponse",
    "AsyncIssuesResourceWithStreamingResponse",
    "StyleGuidesResource",
    "AsyncStyleGuidesResource",
    "StyleGuidesResourceWithRawResponse",
    "AsyncStyleGuidesResourceWithRawResponse",
    "StyleGuidesResourceWithStreamingResponse",
    "AsyncStyleGuidesResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Topic", "AssignedUser"]


class AssignedUser(BaseModel):
    """Information about the assigned user"""

    id: str
    """User ID"""

    email: str
    """User email"""

    name: str
    """User full name"""

    image: Optional[str] = None
    """User profile image URL"""


class Topic(BaseModel):
    """Details about a single Topic"""

    id: str
    """Unique identifier of the topic"""

    baseline: Optional[float] = None
    """Optional baseline score for this topic"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the topic was created"""

    is_verified: bool = FieldInfo(alias="isVerified")
    """
    Whether the topic is verified (true when all active tasks in the topic are
    verified)
    """

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the topic was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this topic"""

    title: str
    """Title of the topic"""

    application_id: Optional[str] = FieldInfo(alias="applicationId", default=None)
    """Optional application ID this topic belongs to"""

    assigned_to: Optional[str] = FieldInfo(alias="assignedTo", default=None)
    """User ID of the assigned user"""

    assigned_user: Optional[AssignedUser] = FieldInfo(alias="assignedUser", default=None)
    """Information about the assigned user"""

    quickstart_id: Optional[str] = FieldInfo(alias="quickstartId", default=None)
    """Optional quickstart ID this topic belongs to"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..tag import Tag
from ..._models import BaseModel

__all__ = ["TagUpdateResponse"]


class TagUpdateResponse(BaseModel):
    """Successful response containing tags"""

    data: List[Tag]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel
from .document import Document

__all__ = ["DocumentCreateResponse"]


class DocumentCreateResponse(BaseModel):
    """Successful response containing the document data"""

    document: Document



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .style_guide_section import StyleGuideSection

__all__ = ["StyleGuide"]


class StyleGuide(BaseModel):
    """A style guide for a specific application"""

    id: str
    """The unique identifier of the style guide"""

    application_id: str = FieldInfo(alias="applicationId")
    """The application ID this style guide belongs to"""

    content: List[StyleGuideSection]

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the style guide was created"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the style guide was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """The organization ID this style guide belongs to"""

    quickstart_id: Optional[str] = FieldInfo(alias="quickstartId", default=None)
    """The ID of the associated quickstart if any"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["IssueSource"]

IssueSource: TypeAlias = Literal["TEST", "TASK", "TOPIC", "SYSTEM", "MONITORING", "API"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["IssueType"]

IssueType: TypeAlias = Literal["BUG", "HUMAN_ANNOTATION", "SUGGESTED_TASK", "USER_SIGNAL"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["TaskListParams"]


class TaskListParams(TypedDict, total=False):
    status: Required[List[Literal["success", "warning", "error", "no-tests"]]]
    """Filter tasks by status"""

    eval_definition_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="evalDefinitionId")]
    """Filter tasks by eval definition ID"""

    limit: int
    """Number of items to include in the result set."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Field to order by in the result set."""

    order_dir: Annotated[Literal["asc", "desc"], PropertyInfo(alias="orderDir")]
    """Order direction."""

    quickstart_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="quickstartId")]
    """Filter tasks by quickstart ID"""

    search: str
    """Search tasks by title or description (case-insensitive partial match)"""

    skip: int
    """Number of items to skip before starting to collect the result set."""

    tag_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="tagId")]
    """Filter tasks by tag ID"""

    topic_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="topicId")]
    """Filter tasks by topic ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["VersionUpdateParams"]


class VersionUpdateParams(TypedDict, total=False):
    id: Required[str]
    """The unique identifier of the document"""

    content: str
    """Updated content for the version"""

    language: str
    """Language of the initial document version"""

    metadata: Dict[str, object]
    """Updated metadata for the version"""

    original_sentences: Annotated[SequenceNotStr[str], PropertyInfo(alias="originalSentences")]
    """Updated array of original sentences from the source"""

    status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]
    """Updated status for the version"""

    title: str
    """Updated title for the version"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tag import Tag
from .._models import BaseModel

__all__ = ["TagUpdateResponse"]


class TagUpdateResponse(BaseModel):
    """Successful response containing the tag data"""

    data: Tag
    """A tag that can be applied to documents for organization"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["StyleGuideListParams"]


class StyleGuideListParams(TypedDict, total=False):
    limit: int
    """Number of items to include in the result set."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Field to order by in the result set."""

    order_dir: Annotated[Literal["asc", "desc"], PropertyInfo(alias="orderDir")]
    """Order direction."""

    skip: int
    """Number of items to skip before starting to collect the result set."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Generic, TypeVar, Optional
from typing_extensions import override

from pydantic import Field as FieldInfo

from ._models import BaseModel
from ._base_client import BasePage, PageInfo, BaseSyncPage, BaseAsyncPage

__all__ = ["OffsetPaginationPagination", "SyncOffsetPagination", "AsyncOffsetPagination"]

_T = TypeVar("_T")


class OffsetPaginationPagination(BaseModel):
    limit: Optional[int] = None

    skip: Optional[int] = None

    total: Optional[int] = None

    total_pages: Optional[int] = FieldInfo(alias="totalPages", default=None)


class SyncOffsetPagination(BaseSyncPage[_T], BasePage[_T], Generic[_T]):
    data: List[_T]
    """The array of returned items"""
    pagination: Optional[OffsetPaginationPagination] = None

    @override
    def _get_page_items(self) -> List[_T]:
        data = self.data
        if not data:
            return []
        return data

    @override
    def next_page_info(self) -> Optional[PageInfo]:
        skip = None
        if self.pagination is not None:
            if self.pagination.skip is not None:
                skip = self.pagination.skip
        if skip is None:
            return None  # type: ignore[unreachable]

        length = len(self._get_page_items())
        current_count = skip + length

        total = None
        if self.pagination is not None:
            if self.pagination.total is not None:
                total = self.pagination.total
        if total is None:
            return None

        if current_count < total:
            return PageInfo(params={"skip": current_count})

        return None


class AsyncOffsetPagination(BaseAsyncPage[_T], BasePage[_T], Generic[_T]):
    data: List[_T]
    """The array of returned items"""
    pagination: Optional[OffsetPaginationPagination] = None

    @override
    def _get_page_items(self) -> List[_T]:
        data = self.data
        if not data:
            return []
        return data

    @override
    def next_page_info(self) -> Optional[PageInfo]:
        skip = None
        if self.pagination is not None:
            if self.pagination.skip is not None:
                skip = self.pagination.skip
        if skip is None:
            return None  # type: ignore[unreachable]

        length = len(self._get_page_items())
        current_count = skip + length

        total = None
        if self.pagination is not None:
            if self.pagination.total is not None:
                total = self.pagination.total
        if total is None:
            return None

        if current_count < total:
            return PageInfo(params={"skip": current_count})

        return None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .document_version import DocumentVersion

__all__ = ["VersionUpdateResponse", "Document", "DocumentScrapeJob", "DocumentScrapeJobPage"]


class DocumentScrapeJobPage(BaseModel):
    url: str
    """The URL of the page"""

    category: Optional[str] = None
    """The category of the page"""

    description: Optional[str] = None
    """The description of the page"""

    title: Optional[str] = None
    """The title of the page"""


class DocumentScrapeJob(BaseModel):
    """Optional scrape job that generated this document"""

    id: str
    """The unique identifier of the scrape job"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the scrape job was created"""

    initiated_by: str = FieldInfo(alias="initiatedBy")
    """User ID who initiated the scrape job"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the scrape job was last modified"""

    name: str
    """The name/title of the scrape job"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns the scrape job"""

    status: Literal["MAPPING", "PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]
    """Current status of the scrape job"""

    url: str
    """The URL that was scraped"""

    application_id: Optional[str] = FieldInfo(alias="applicationId", default=None)
    """Optional application ID this scrape job belongs to"""

    pages: Optional[List[DocumentScrapeJobPage]] = None
    """The pages scraped from the URL"""


class Document(BaseModel):
    """
    A Core Document represents a piece of content that can be organized hierarchically with parent-child relationships and supports versioning
    """

    id: str
    """Unique identifier of the document"""

    assignee: str
    """User ID of the person assigned to this document"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the document was created"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the document was last modified"""

    optimized: bool
    """Whether the document has been optimized"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this document"""

    type: Literal["KNOWLEDGE", "POLICY"]
    """Type of the document. Valid options: KNOWLEDGE, POLICY."""

    application_id: Optional[str] = FieldInfo(alias="applicationId", default=None)
    """Optional application ID this document belongs to"""

    quickstart_id: Optional[str] = FieldInfo(alias="quickstartId", default=None)
    """Optional ID of the QuickstartV2 this document belongs to"""

    scrape_job: Optional[DocumentScrapeJob] = FieldInfo(alias="scrapeJob", default=None)
    """Optional scrape job that generated this document"""

    scrape_job_id: Optional[str] = FieldInfo(alias="scrapeJobId", default=None)
    """Optional ID of the scrape job that generated this document"""

    topic_id: Optional[str] = FieldInfo(alias="topicId", default=None)
    """Optional ID of the topic this document belongs to"""


class VersionUpdateResponse(BaseModel):
    """Response containing a specific document version"""

    document: Document
    """
    A Core Document represents a piece of content that can be organized
    hierarchically with parent-child relationships and supports versioning
    """

    version: DocumentVersion
    """A specific version of a document with its content and metadata"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TraceListParams"]


class TraceListParams(TypedDict, total=False):
    end_date: Annotated[Union[str, datetime], PropertyInfo(alias="endDate", format="iso8601")]
    """Filter traces created before this date (inclusive)."""

    has_error: Annotated[bool, PropertyInfo(alias="hasError")]
    """Filter traces with or without errors."""

    limit: int
    """Number of items to include in the result set."""

    max_cost: Annotated[float, PropertyInfo(alias="maxCost")]
    """Filter traces with total cost less than or equal to this value."""

    max_duration: Annotated[int, PropertyInfo(alias="maxDuration")]
    """Filter traces with total duration (ms) less than or equal to this value."""

    max_score: Annotated[float, PropertyInfo(alias="maxScore")]
    """Filter traces with eval score less than or equal to this value."""

    metadata_key: Annotated[str, PropertyInfo(alias="metadataKey")]
    """Metadata key to filter on. Must be used together with metadataValue."""

    metadata_value: Annotated[str, PropertyInfo(alias="metadataValue")]
    """Metadata value to filter on. Must be used together with metadataKey."""

    min_cost: Annotated[float, PropertyInfo(alias="minCost")]
    """Filter traces with total cost greater than or equal to this value."""

    min_duration: Annotated[int, PropertyInfo(alias="minDuration")]
    """Filter traces with total duration (ms) greater than or equal to this value."""

    min_score: Annotated[float, PropertyInfo(alias="minScore")]
    """Filter traces with eval score greater than or equal to this value."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Field to order by in the result set."""

    order_dir: Annotated[Literal["asc", "desc"], PropertyInfo(alias="orderDir")]
    """Order direction."""

    reference_id: Annotated[str, PropertyInfo(alias="referenceId")]
    """Filter traces by reference ID"""

    search: str
    """
    Full-text search across trace step content fields (input, output, toolInput,
    toolOutput, content, query, result).
    """

    skip: int
    """Number of items to skip before starting to collect the result set."""

    start_date: Annotated[Union[str, datetime], PropertyInfo(alias="startDate", format="iso8601")]
    """Filter traces created after this date (inclusive)."""

    test_id: Annotated[str, PropertyInfo(alias="testId")]
    """Filter traces by test ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["DocumentListParams"]


class DocumentListParams(TypedDict, total=False):
    assignee: str
    """Filter by assignee user ID"""

    end_date: Annotated[Union[str, datetime], PropertyInfo(alias="endDate", format="iso8601")]
    """Filter documents created before this date (inclusive)."""

    limit: int
    """Number of items to include in the result set."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Field to order by in the result set."""

    order_dir: Annotated[Literal["asc", "desc"], PropertyInfo(alias="orderDir")]
    """Order direction."""

    scrape_job_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="scrapeJobId")]
    """Filter by scrape job ID. Supports multiple values."""

    search: str
    """Search in document version title and content"""

    skip: int
    """Number of items to skip before starting to collect the result set."""

    start_date: Annotated[Union[str, datetime], PropertyInfo(alias="startDate", format="iso8601")]
    """Filter documents created after this date (inclusive)."""

    status: List[Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]]
    """
    Filter by document version status (filters documents by their active version
    status). Supports multiple values.
    """

    tag_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="tagId")]
    """Filter documents by tag ID"""

    type: Literal["KNOWLEDGE", "POLICY"]
    """Filter by document type. Defaults to KNOWLEDGE if not specified."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ValidateWebhookValidateParams", "Body", "BodyExperiment"]


class ValidateWebhookValidateParams(TypedDict, total=False):
    body: Required[Body]
    """The payload received from Avido. Use this in signature verification."""

    signature: Required[str]
    """HMAC signature for the request body."""

    timestamp: Required[str]
    """Timestamp for the request.

    Accepts unix milliseconds (string/number) and ISO date strings.
    """


class BodyExperiment(TypedDict, total=False):
    """Payload containing the experiment details."""

    experiment_id: Required[Annotated[str, PropertyInfo(alias="experimentId")]]
    """The unique identifier of the experiment"""

    experiment_variant_id: Required[Annotated[str, PropertyInfo(alias="experimentVariantId")]]
    """The unique identifier of the experiment variant"""

    overrides: Required[Dict[str, Dict[str, object]]]


class Body(TypedDict, total=False):
    """The payload received from Avido. Use this in signature verification."""

    application_id: Required[Annotated[str, PropertyInfo(alias="applicationId")]]
    """The unique identifier of the application this test belongs to."""

    prompt: Required[Union[str, Dict[str, object]]]
    """The user prompt that triggered the test run."""

    test_id: Required[Annotated[str, PropertyInfo(alias="testId")]]
    """The unique identifier for the test run."""

    experiment: BodyExperiment
    """Payload containing the experiment details."""

    metadata: Dict[str, object]
    """Metadata from the originating task. Only included when metadata is available."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal

import httpx

from ..types import test_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncOffsetPagination, AsyncOffsetPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.run_type import RunType
from ..types.test_list_response import TestListResponse
from ..types.test_retrieve_response import TestRetrieveResponse

__all__ = ["TestsResource", "AsyncTestsResource"]


class TestsResource(SyncAPIResource):
    __test__ = False

    @cached_property
    def with_raw_response(self) -> TestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return TestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return TestsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TestRetrieveResponse:
        """
        Retrieves detailed information about a specific test.

        Args:
          id: The unique identifier of the test

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/tests/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TestRetrieveResponse,
        )

    def list(
        self,
        *,
        pass_rate_statuses: List[Literal["success", "warning", "error"]],
        end_date: Union[str, datetime] | Omit = omit,
        eval_definition_id: SequenceNotStr[str] | Omit = omit,
        experiment_variant_id: SequenceNotStr[str] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        run_type: List[RunType] | Omit = omit,
        skip: int | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        status: List[Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]] | Omit = omit,
        tag_id: SequenceNotStr[str] | Omit = omit,
        task_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncOffsetPagination[TestListResponse]:
        """
        Retrieves a paginated list of tests with optional filtering.

        Args:
          pass_rate_statuses: Filter by pass rate status badges (success: >75%, warning: 51-75%, error: ≤50%)

          end_date: Filter eval runs before this date (inclusive).

          eval_definition_id: Filter tests by eval definition ID

          experiment_variant_id: Filter tests by experiment variant ID

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          run_type: Filter tests by run type (MANUAL, SCHEDULED, EXPERIMENT)

          skip: Number of items to skip before starting to collect the result set.

          start_date: Filter eval runs after this date (inclusive).

          status: Filter by test status (e.g. COMPLETED, FAILED)

          tag_id: Filter tests by the associated task's tag IDs. Use '**none**' to filter for
              tests with untagged tasks.

          task_id: Filter tests by task ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/tests",
            page=SyncOffsetPagination[TestListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "pass_rate_statuses": pass_rate_statuses,
                        "end_date": end_date,
                        "eval_definition_id": eval_definition_id,
                        "experiment_variant_id": experiment_variant_id,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "run_type": run_type,
                        "skip": skip,
                        "start_date": start_date,
                        "status": status,
                        "tag_id": tag_id,
                        "task_id": task_id,
                    },
                    test_list_params.TestListParams,
                ),
            ),
            model=TestListResponse,
        )


class AsyncTestsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTestsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncTestsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTestsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncTestsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TestRetrieveResponse:
        """
        Retrieves detailed information about a specific test.

        Args:
          id: The unique identifier of the test

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/tests/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TestRetrieveResponse,
        )

    def list(
        self,
        *,
        pass_rate_statuses: List[Literal["success", "warning", "error"]],
        end_date: Union[str, datetime] | Omit = omit,
        eval_definition_id: SequenceNotStr[str] | Omit = omit,
        experiment_variant_id: SequenceNotStr[str] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        run_type: List[RunType] | Omit = omit,
        skip: int | Omit = omit,
        start_date: Union[str, datetime] | Omit = omit,
        status: List[Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]] | Omit = omit,
        tag_id: SequenceNotStr[str] | Omit = omit,
        task_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[TestListResponse, AsyncOffsetPagination[TestListResponse]]:
        """
        Retrieves a paginated list of tests with optional filtering.

        Args:
          pass_rate_statuses: Filter by pass rate status badges (success: >75%, warning: 51-75%, error: ≤50%)

          end_date: Filter eval runs before this date (inclusive).

          eval_definition_id: Filter tests by eval definition ID

          experiment_variant_id: Filter tests by experiment variant ID

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          run_type: Filter tests by run type (MANUAL, SCHEDULED, EXPERIMENT)

          skip: Number of items to skip before starting to collect the result set.

          start_date: Filter eval runs after this date (inclusive).

          status: Filter by test status (e.g. COMPLETED, FAILED)

          tag_id: Filter tests by the associated task's tag IDs. Use '**none**' to filter for
              tests with untagged tasks.

          task_id: Filter tests by task ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/tests",
            page=AsyncOffsetPagination[TestListResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "pass_rate_statuses": pass_rate_statuses,
                        "end_date": end_date,
                        "eval_definition_id": eval_definition_id,
                        "experiment_variant_id": experiment_variant_id,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "run_type": run_type,
                        "skip": skip,
                        "start_date": start_date,
                        "status": status,
                        "tag_id": tag_id,
                        "task_id": task_id,
                    },
                    test_list_params.TestListParams,
                ),
            ),
            model=TestListResponse,
        )


class TestsResourceWithRawResponse:
    __test__ = False

    def __init__(self, tests: TestsResource) -> None:
        self._tests = tests

        self.retrieve = to_raw_response_wrapper(
            tests.retrieve,
        )
        self.list = to_raw_response_wrapper(
            tests.list,
        )


class AsyncTestsResourceWithRawResponse:
    def __init__(self, tests: AsyncTestsResource) -> None:
        self._tests = tests

        self.retrieve = async_to_raw_response_wrapper(
            tests.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            tests.list,
        )


class TestsResourceWithStreamingResponse:
    __test__ = False

    def __init__(self, tests: TestsResource) -> None:
        self._tests = tests

        self.retrieve = to_streamed_response_wrapper(
            tests.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            tests.list,
        )


class AsyncTestsResourceWithStreamingResponse:
    def __init__(self, tests: AsyncTestsResource) -> None:
        self._tests = tests

        self.retrieve = async_to_streamed_response_wrapper(
            tests.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            tests.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["IssuePriority"]

IssuePriority: TypeAlias = Literal["LOW", "MEDIUM", "HIGH"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .task import Task
from .._models import BaseModel

__all__ = ["TaskCreateResponse"]


class TaskCreateResponse(BaseModel):
    """Successful response containing the task data"""

    task: Task
    """
    A task that represents a specific job-to-be-done by the LLM in the user
    application.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["TagUpdateParams"]


class TagUpdateParams(TypedDict, total=False):
    tag_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="tagIds")]]
    """Array of tag IDs to assign to the resource"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["DocumentVersion"]


class DocumentVersion(BaseModel):
    """A specific version of a document with its content and metadata"""

    id: str
    """Unique identifier of the document version"""

    content: str
    """Content of the document version"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the document version was created"""

    document_id: str = FieldInfo(alias="documentId")
    """ID of the document this version belongs to"""

    language: str
    """Language of the document version"""

    metadata: Dict[str, object]
    """Optional metadata associated with the document version"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the document version was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this document version"""

    original_sentences: List[str] = FieldInfo(alias="originalSentences")
    """Array of original sentences from the source"""

    status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]
    """Status of the document.

    Valid options: DRAFT, REVIEW, APPROVED, ARCHIVED, ACTIVE.
    """

    title: str
    """Title of the document version"""

    type: Literal["KNOWLEDGE", "POLICY"]
    """Type of the document. Valid options: KNOWLEDGE, POLICY."""

    version_number: int = FieldInfo(alias="versionNumber")
    """Version number of this document version"""

    application_id: Optional[str] = FieldInfo(alias="applicationId", default=None)
    """Optional application ID this document version belongs to"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["TestResult"]


class TestResult(BaseModel):
    __test__ = False
    average_score: float = FieldInfo(alias="averageScore")

    failed: int

    passed: int

    pass_rate: float = FieldInfo(alias="passRate")

    total: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Application"]


class Application(BaseModel):
    """Application configuration and metadata"""

    id: str
    """Unique identifier of the application"""

    context: str
    """Context/instructions for the application"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the application was created"""

    description: str
    """Description of the application"""

    environment: Literal["DEV", "PROD"]
    """Environment of the application. Defaults to DEV."""

    language: str
    """Language of the application"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the application was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this application"""

    slug: str
    """URL-friendly slug for the application"""

    title: str
    """Title of the application"""

    type: Literal["CHATBOT", "AGENT"]
    """Type of the application. Valid values are CHATBOT or AGENT."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["TaskUpdateParams"]


class TaskUpdateParams(TypedDict, total=False):
    description: str
    """A short description of the task"""

    input_examples: Annotated[SequenceNotStr[str], PropertyInfo(alias="inputExamples")]
    """Example inputs for the task"""

    is_verified: Annotated[bool, PropertyInfo(alias="isVerified")]
    """Whether the task has been verified"""

    metadata: Optional[Dict[str, object]]
    """Replace the existing task metadata.

    Use null to clear all metadata for the task.
    """

    simulated_prompt_schema: Annotated[Optional[Dict[str, object]], PropertyInfo(alias="simulatedPromptSchema")]
    """
    JSON schema that defines the structure for user prompts that should be generated
    for tests
    """

    title: str
    """The title of the task"""

    topic_id: Annotated[Optional[str], PropertyInfo(alias="topicId")]
    """ID of the topic this task belongs to"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["StyleGuideSection"]


class StyleGuideSection(BaseModel):
    """A section for a style guide"""

    approved: bool
    """Whether or not the section has been approved"""

    content: str
    """The content of the section in markdown"""

    heading: str
    """The heading of the section"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .trace import Trace
from .._models import BaseModel

__all__ = ["TraceRetrieveByTestResponse"]


class TraceRetrieveByTestResponse(BaseModel):
    """Successful response containing a single trace object"""

    data: Trace
    """A trace grouping related steps (e.g. a user-agent interaction or conversation)."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["DefinitionLinkParams"]


class DefinitionLinkParams(TypedDict, total=False):
    eval_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="evalIds")]]
    """Array of evaluation definition IDs to link/unlink.

    Can be a single ID or multiple IDs.
    """

    task_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="taskIds")]]
    """Array of task IDs to link/unlink the evaluation definitions to/from.

    Can be a single ID or multiple IDs.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .issue_type import IssueType
from .issue_source import IssueSource
from .issue_priority import IssuePriority

__all__ = ["IssueCreateParams"]


class IssueCreateParams(TypedDict, total=False):
    source: Required[IssueSource]
    """Where the issue originated from"""

    title: Required[str]
    """Title of the issue"""

    annotation_id: Annotated[str, PropertyInfo(alias="annotationId")]
    """Associated annotation ID if related to an annotation"""

    description: Optional[str]
    """Detailed description of the issue"""

    eval_definition_id: Annotated[str, PropertyInfo(alias="evalDefinitionId")]
    """Associated evaluation definition ID if issue came from an evaluation"""

    experiment_id: Annotated[str, PropertyInfo(alias="experimentId")]
    """Associated experiment ID to link issue to an experiment"""

    parent_id: Annotated[str, PropertyInfo(alias="parentId")]
    """Parent issue ID for creating sub-issues"""

    priority: IssuePriority
    """Priority level of the issue"""

    task_id: Annotated[str, PropertyInfo(alias="taskId")]
    """Associated task ID if issue came from a task"""

    test_id: Annotated[str, PropertyInfo(alias="testId")]
    """Associated test ID if issue came from a test"""

    topic_id: Annotated[str, PropertyInfo(alias="topicId")]
    """Associated topic ID if issue came from a topic"""

    trace_id: Annotated[str, PropertyInfo(alias="traceId")]
    """Associated trace ID for monitoring/debugging"""

    type: IssueType
    """Type/category of the issue"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from . import eval_definition as _eval_definition
from .._models import BaseModel

__all__ = ["Task", "EvalDefinition", "EvalDefinitionConfig", "TaskSchedule"]


class EvalDefinitionConfig(BaseModel):
    expected: Union[str, List[str]]


class EvalDefinition(BaseModel):
    eval_definition: _eval_definition.EvalDefinition = FieldInfo(alias="evalDefinition")

    config: Optional[EvalDefinitionConfig] = None


class TaskSchedule(BaseModel):
    """Task schedule schema"""

    application_id: str = FieldInfo(alias="applicationId")

    criticality: Literal["LOW", "MEDIUM", "HIGH"]

    cron: str

    task_id: str = FieldInfo(alias="taskId")

    last_run_at: Optional[datetime] = FieldInfo(alias="lastRunAt", default=None)

    next_run_at: Optional[datetime] = FieldInfo(alias="nextRunAt", default=None)


class Task(BaseModel):
    """
    A task that represents a specific job-to-be-done by the LLM in the user application.
    """

    id: str
    """The unique identifier of the task"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the task was created"""

    description: str
    """The task description"""

    eval_definitions: List[EvalDefinition] = FieldInfo(alias="evalDefinitions")

    input_examples: List[str] = FieldInfo(alias="inputExamples")
    """Example inputs for the task"""

    is_verified: bool = FieldInfo(alias="isVerified")
    """Whether the task has been verified"""

    metadata: Dict[str, object]
    """Optional metadata associated with the task.

    Returns null when no metadata is stored.
    """

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the task was last modified"""

    monitoring_pass_rate: Optional[float] = FieldInfo(alias="monitoringPassRate", default=None)
    """The 30 day pass rate for monitoring runs only, measured in percentage.

    Null when no monitoring runs exist.
    """

    pass_rate: Optional[float] = FieldInfo(alias="passRate", default=None)
    """
    The 30 day pass rate for the task measured in percentage (excludes monitoring
    runs). Null when no tests have been run.
    """

    status: Literal["DEDUCED", "DRAFT", "ACTIVE"]
    """The status of the task.

    DEDUCED tasks are created from unmatched traces, DRAFT tasks are user-facing
    drafts, and ACTIVE tasks are production tasks.
    """

    title: str
    """The title of the task"""

    type: Literal["STATIC", "NORMAL"]
    """The type of task.

    Normal tasks have a dynamic user prompt, while adversarial tasks have a fixed
    user prompt.
    """

    last_test: Optional[datetime] = FieldInfo(alias="lastTest", default=None)
    """The date and time this task was last tested"""

    parent_id: Optional[str] = FieldInfo(alias="parentId", default=None)
    """The ID of the parent task (for DEDUCED tasks linked to a DRAFT)"""

    quickstart_id: Optional[str] = FieldInfo(alias="quickstartId", default=None)
    """The ID of the quickstart this task was generated from"""

    simulated_prompt_schema: Optional[Dict[str, object]] = FieldInfo(alias="simulatedPromptSchema", default=None)
    """
    JSON schema that defines the structure for user prompts that should be generated
    for tests
    """

    task_schedule: Optional[TaskSchedule] = FieldInfo(alias="taskSchedule", default=None)
    """Task schedule schema"""

    topic_id: Optional[str] = FieldInfo(alias="topicId", default=None)
    """The ID of the topic this task belongs to"""

    trace_id: Optional[str] = FieldInfo(alias="traceId", default=None)
    """The ID of the trace this task was deduced from (only for DEDUCED tasks)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import IngestCreateResponse
from tests.utils import assert_matches_type
from avido._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestIngest:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        ingest = client.ingest.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        )
        assert_matches_type(IngestCreateResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.ingest.with_raw_response.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = response.parse()
        assert_matches_type(IngestCreateResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.ingest.with_streaming_response.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = response.parse()
            assert_matches_type(IngestCreateResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncIngest:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        ingest = await async_client.ingest.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        )
        assert_matches_type(IngestCreateResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.ingest.with_raw_response.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = await response.parse()
        assert_matches_type(IngestCreateResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.ingest.with_streaming_response.create(
            events=[
                {
                    "timestamp": parse_datetime("2025-01-01T12:00:00Z"),
                    "type": "trace",
                },
                {
                    "event": "start",
                    "input": [
                        {
                            "role": "user",
                            "content": "Tell me a joke.",
                        }
                    ],
                    "model_id": "gpt-4o-2024-08-06",
                    "timestamp": parse_datetime("2025-01-01T12:01:00Z"),
                    "type": "llm",
                },
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = await response.parse()
            assert_matches_type(IngestCreateResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["CoreTag"]


class CoreTag(BaseModel):
    id: str
    """Unique identifier of the tag"""

    color: str
    """Hex color code for the tag"""

    name: str
    """Name of the tag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["TagCreateParams"]


class TagCreateParams(TypedDict, total=False):
    name: Required[str]
    """Name of the tag"""

    color: str
    """Hex color code for the tag"""

    description: str
    """Optional description of the tag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)

__all__ = [
    "VersionsResource",
    "AsyncVersionsResource",
    "VersionsResourceWithRawResponse",
    "AsyncVersionsResourceWithRawResponse",
    "VersionsResourceWithStreamingResponse",
    "AsyncVersionsResourceWithStreamingResponse",
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["ValidateWebhookValidateResponse"]


class ValidateWebhookValidateResponse(BaseModel):
    """Response object indicating whether the webhook was valid."""

    valid: bool
    """Indicates if the webhook payload was successfully validated."""
